powered by
Black Schiles Model function Calculating Function Using the Black-Schiles Option Pricing Model
black_schiles( mode = 1, current_price, stock_price, conver_price, stock_var, time, interest_rate, netdebt_value )
Option value per share(numeric)
Two calculation methods, respectively 1 and 2
Current price of convertible bonds
Positive stock price
Conversion price
Standard deviation of annualized rate of return for underlying stocks
Expiration time (annualized remaining period)
Risk-free continuous compound interest rate
Pure debt value
result<-black_schiles(mode=1,current_price=122.82, stock_price=5.9,conver_price=5.43,stock_var=0.2616,time=1.353, interest_rate=0.018482, netdebt_value=104.05)
Run the code above in your browser using DataLab