Learn R Programming

convertbonds (version 0.1.0)

monte_carlo: Monte Carlo simulation function Predicting Theoretical Value of Options per Share Using Monte Carlo Simulations

Description

Monte Carlo simulation function Predicting Theoretical Value of Options per Share Using Monte Carlo Simulations

Usage

monte_carlo(I, M, S_0, K, Time, r, sigma)

Value

No return value, called for side effects

Arguments

I

number ofsimulation

M

number of time steps

S_0

The initial price of the underlying stock

K

Exercise price (conversion price)

Time

Simulate paths over time intervals

r

risk free rate

sigma

Volatility (Standard Deviation of Return)

Examples

Run this code
monte_carlo(I=10000,M=50,S_0=5.9,K=5.43,T=1.353,r=0.018482,sigma=0.2616)

Run the code above in your browser using DataLab